@@ -76,34 +76,35 @@
 #'
 #' @export
 ggscatterstats <- function(
-    data,
-    x,
-    y,
-    type = "parametric",
-    conf.level = 0.95,
-    bf.prior = 0.707,
-    bf.message = TRUE,
-    tr = 0.2,
-    digits = 2L,
-    results.subtitle = TRUE,
-    label.var = NULL,
-    label.expression = NULL,
-    marginal = TRUE,
-    point.args = list(size = 3, alpha = 0.4, stroke = 0),
-    point.width.jitter = 0,
-    point.height.jitter = 0,
-    point.label.args = list(size = 3, max.overlaps = 1e6),
-    smooth.line.args = list(linewidth = 1.5, color = "blue", method = "lm", formula = y ~ x),
-    xsidehistogram.args = list(fill = "#009E73", color = "black", na.rm = TRUE),
-    ysidehistogram.args = list(fill = "#D55E00", color = "black", na.rm = TRUE),
-    xlab = NULL,
-    ylab = NULL,
-    title = NULL,
-    subtitle = NULL,
-    caption = NULL,
-    ggtheme = ggstatsplot::theme_ggstatsplot(),
-    ggplot.component = NULL,
-    ...) {
+  data,
+  x,
+  y,
+  type = "parametric",
+  conf.level = 0.95,
+  bf.prior = 0.707,
+  bf.message = TRUE,
+  tr = 0.2,
+  digits = 2L,
+  results.subtitle = TRUE,
+  label.var = NULL,
+  label.expression = NULL,
+  marginal = TRUE,
+  point.args = list(size = 3, alpha = 0.4, stroke = 0),
+  point.width.jitter = 0,
+  point.height.jitter = 0,
+  point.label.args = list(size = 3, max.overlaps = 1e6),
+  smooth.line.args = list(linewidth = 1.5, color = "blue", method = "lm", formula = y ~ x),
+  xsidehistogram.args = list(fill = "#009E73", color = "black", na.rm = TRUE),
+  ysidehistogram.args = list(fill = "#D55E00", color = "black", na.rm = TRUE),
+  xlab = NULL,
+  ylab = NULL,
+  title = NULL,
+  subtitle = NULL,
+  caption = NULL,
+  ggtheme = ggstatsplot::theme_ggstatsplot(),
+  ggplot.component = NULL,
+  ...
+) {
   # data ---------------------------------------
 
   # make sure both quoted and unquoted arguments are allowed
@@ -251,11 +252,12 @@ ggscatterstats <- function(
 #' )
 #' @export
 grouped_ggscatterstats <- function(
-    data,
-    ...,
-    grouping.var,
-    plotgrid.args = list(),
-    annotation.args = list()) {
+  data,
+  ...,
+  grouping.var,
+  plotgrid.args = list(),
+  annotation.args = list()
+) {
   .grouped_list(data, {{ grouping.var }}) %>%
     purrr::pmap(.f = ggscatterstats, ...) %>%
     combine_plots(plotgrid.args, annotation.args)
